@@ -1,22 +1,38 @@
 from __future__ import absolute_import
 
 import functools
+import sys
 
 import six
 from past.builtins import map
 
-from . import blocks, exception, legos, pedrpc, primitives
+from . import blocks, exception, legos, primitives
 from .blocks import Block, Checksum, Repeat, Request, REQUESTS, Size
+from .connections import (
+    BaseSocketConnection,
+    FileConnection,
+    ip_constants,
+    ISerialLike,
+    ITargetConnection,
+    RawL2SocketConnection,
+    RawL3SocketConnection,
+    SerialConnection,
+    SerialConnectionLowLevel,
+    SocketConnection,
+    SSLSocketConnection,
+    TCPSocketConnection,
+    UDPSocketConnection,
+)
 from .constants import BIG_ENDIAN, DEFAULT_PROCMON_PORT, LITTLE_ENDIAN
 from .event_hook import EventHook
-from .exception import MustImplementException, SizerNotUtilizedError, SullyRuntimeError
+from .exception import MustImplementException, SizerNotUtilizedError, SullyRuntimeError, BoofuzzFailure
 from .fuzz_logger import FuzzLogger
 from .fuzz_logger_csv import FuzzLoggerCsv
 from .fuzz_logger_curses import FuzzLoggerCurses
 from .fuzz_logger_text import FuzzLoggerText
 from .ifuzz_logger import IFuzzLogger
 from .ifuzz_logger_backend import IFuzzLoggerBackend
-from .itarget_connection import ITargetConnection
+from .monitors import BaseMonitor, CallbackMonitor, NetworkMonitor, pedrpc, ProcessMonitor
 from .primitives import (
     BasePrimitive,
     BitField,
@@ -33,24 +49,37 @@ from .primitives import (
     String,
     Word,
 )
-from .serial_connection import SerialConnection
+from .repeater import CountRepeater, Repeater, TimeRepeater
 from .sessions import open_test_run, Session, Target
-from .socket_connection import SocketConnection
+
+# workaround to make Tornado work in Python 3.8
+# https://github.com/tornadoweb/tornado/issues/2608
+if sys.platform == "win32" and sys.version_info >= (3, 8):
+    import asyncio
+
+    # noinspection PyUnresolvedReferences
+    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())  # pytype: disable=module-attr
 
 __all__ = [
+    "BaseMonitor",
     "BasePrimitive",
+    "BaseSocketConnection",
     "BIG_ENDIAN",
     "BitField",
     "Block",
     "blocks",
+    "BoofuzzFailure",
     "Byte",
     "Bytes",
+    "CallbackMonitor",
     "Checksum",
+    "CountRepeater",
     "DEFAULT_PROCMON_PORT",
     "Delim",
     "DWord",
     "EventHook",
     "exception",
+    "FileConnection",
     "FromFile",
     "FuzzLogger",
     "FuzzLoggerCsv",
@@ -59,17 +88,24 @@ __all__ = [
     "Group",
     "IFuzzLogger",
     "IFuzzLoggerBackend",
+    "ip_constants",
+    "ISerialLike",
     "ITargetConnection",
     "legos",
     "LITTLE_ENDIAN",
     "Mirror",
     "MustImplementException",
+    "NetworkMonitor",
     "open_test_run",
     "pedrpc",
     "primitives",
+    "ProcessMonitor",
     "QWord",
     "RandomData",
+    "RawL2SocketConnection",
+    "RawL3SocketConnection",
     "Repeat",
+    "Repeater",
     "Request",
     "REQUESTS",
     "s_bigword",
@@ -117,18 +153,23 @@ __all__ = [
     "s_update",
     "s_word",
     "SerialConnection",
+    "SerialConnectionLowLevel",
     "Session",
     "Size",
     "SizerNotUtilizedError",
     "SocketConnection",
+    "SSLSocketConnection",
     "Static",
     "String",
     "SullyRuntimeError",
     "Target",
+    "TCPSocketConnection",
+    "TimeRepeater",
+    "UDPSocketConnection",
     "Word",
 ]
 
-__version__ = "0.1.6"
+__version__ = "0.2.0"
 
 
 # REQUEST MANAGEMENT
@@ -145,7 +186,7 @@ def s_get(name=None):
     :type  name: str
     :param name: (Optional, def=None) Name of request to return or current request if name is None.
 
-    :rtype:  blocks.request
+    :rtype:  blocks.Request
     :return: The requested request.
     """
 
@@ -716,7 +757,7 @@ def s_byte(
 
 def s_bytes(value, size=None, padding=b"\x00", fuzzable=True, max_len=None, name=None):
     """
-    Push a bytes field onto the current block stack.
+    Push a bytes field of arbitrary length onto the current block stack.
 
     :type  value:        bytes
     :param value:        Default binary value
